@@ -33,6 +33,7 @@ const CheckIn = imports.checkIn;
 const ContactPlace = imports.contactPlace;
 const Format = imports.format;
 const Geoclue = imports.geoclue;
+const GeocodeFactory = imports.geocode;
 const MainWindow = imports.mainWindow;
 const Maps = imports.gi.GnomeMaps;
 const OSMEdit = imports.osmEdit;
@@ -42,6 +43,7 @@ const RoutingDelegator = imports.routingDelegator;
 const RouteQuery = imports.routeQuery;
 const Settings = imports.settings;
 const Utils = imports.utils;
+const URIS = imports.uris;
 
 // used globally
 var application = null;
@@ -96,7 +98,7 @@ var Application = GObject.registerClass({
         /* Needed to be able to use in UI files */
         _ensuredTypes.forEach((type) => GObject.type_ensure(type));
 
-        super._init({ application_id: 'org.gnome.Maps',
+        super._init({ application_id: pkg.name,
                       flags: Gio.ApplicationFlags.HANDLES_OPEN |
                              Gio.ApplicationFlags.HANDLES_COMMAND_LINE });
         this._connected = false;
@@ -123,6 +125,14 @@ var Application = GObject.registerClass({
                              GLib.OptionArg.NONE,
                              _("Ignore network availability"),
                              null);
+
+        this.add_main_option('search',
+                             'S'.charCodeAt(0),
+                             GLib.OptionFlags.NONE,
+                             GLib.OptionArg.STRING,
+                             _("Search for places"),
+                             null);
+
         /* due to https://gitlab.gnome.org/GNOME/gjs/-/issues/330 the
          * description for the remaining args needs to be passed as both
          * description and arg_description
@@ -179,6 +189,20 @@ var Application = GObject.registerClass({
         dialog.connect('response', () => dialog.destroy());
     }
 
+    _onSearchActivate(action, parameter) {
+        this._createWindow();
+        this._mainWindow.present();
+
+        let query = parameter.deep_unpack();
+        let mapView = this._mainWindow.mapView;
+
+        if (mapView.view.realized)
+            this._openSearchQuery(query);
+        else
+            mapView.view.connect('notify::realized',
+                                 this._openSearchQuery.bind(this, query));
+    }
+
     _addContacts() {
         let contacts = contactStore.get_contacts();
 
@@ -227,12 +251,6 @@ var Application = GObject.registerClass({
         }
     }
 
-    _onNightModeChange(action) {
-        let state = action.get_state();
-        let gtkSettings = Gtk.Settings.get_default();
-        gtkSettings.gtk_application_prefer_dark_theme = state.get_boolean();
-    }
-
     vfunc_startup() {
         super.vfunc_startup();
 
@@ -252,10 +270,9 @@ var Application = GObject.registerClass({
             'osm-account-setup': {
                 onActivate: this._onOsmAccountSetupActivate.bind(this)
             },
-            'night-mode': {
-                paramType:     'b',
-                onChangeState: this._onNightModeChange.bind(this),
-                setting:       'night-mode'
+            'search': {
+                paramType: 's',
+                onActivate: this._onSearchActivate.bind(this)
             },
             'quit': {
                 onActivate: () => this.quit(),
@@ -263,11 +280,9 @@ var Application = GObject.registerClass({
             }
         }, settings);
 
-        // set dark theme when night-mode is enabled
-        let gtkSettings = Gtk.Settings.get_default();
 
-        gtkSettings.gtk_application_prefer_dark_theme =
-            settings.get('night-mode');
+        this._styleManager = Hdy.StyleManager.get_default();
+        this._styleManager.set_color_scheme(Hdy.ColorScheme.PREFER_LIGHT);
 
         Gtk.IconTheme.get_default().append_search_path(GLib.build_filenamev([pkg.pkgdatadir,
                                                                              'icons']));
@@ -324,18 +339,86 @@ var Application = GObject.registerClass({
         let scheme = GLib.uri_parse_scheme(uri);
 
         if (scheme === 'geo') {
-            /* we get an uri that looks like geo:///lat,lon, remove slashes */
+            // we get a URI that looks like geo:///lat,lon, remove slashes
             let geoURI = uri.replace(/\//g, '');
             this._mainWindow.mapView.goToGeoURI(geoURI);
         } else if (scheme === 'http' || scheme === 'https') {
             this._mainWindow.mapView.goToHttpURL(uri);
+        } else if (scheme === 'maps') {
+            // we get a URI that looks like maps:///q=Search, remove slashes
+            let mapsURI = uri.replace(/\//g, '');
+            this._openMapsUri(mapsURI);
         } else {
             this._mainWindow.mapView.openShapeLayers(files);
         }
     }
 
+    _openMapsUri(uri) {
+        let query = URIS.parseMapsURI(uri);
+
+        if (query)
+            this._openSearchQuery(query);
+        else
+            this._invalidMapsUri(uri);
+    }
+
+    _openSearchQuery(query) {
+        let cancellable = new Gio.Cancellable();
+
+        /* unless there's exactly one place (which should be focused) in
+         * the results, let the stored location be used on startup
+         */
+        normalStartup = true;
+        this.connect('shutdown', () => cancellable.cancel());
+        GeocodeFactory.getGeocoder().search(query, null, null, cancellable,
+                                            (places, error) => {
+            if (error) {
+                Utils.showDialog(_("An error has occurred"),
+                                 Gtk.MessageType.ERROR, this._mainWindow);
+            } else {
+                // clear search entry
+                this._mainWindow.placeEntry.text = '';
+
+                if (places) {
+                    /* if there's only one place in results, show it directly
+                     * with it's bubble, otherwise present the results in the
+                     * search popover
+                     */
+                    if (places?.length === 1) {
+                        /* don't use the stored location on startup, as we're
+                         * zooming in directly on the place
+                         */
+                        normalStartup = false;
+                        this._mainWindow.mapView.showPlace(places[0], true);
+                    } else {
+                        this._mainWindow.placeEntry.grab_focus();
+                        this._mainWindow.placeEntry.updateResults(places, query,
+                                                                  false);
+                    }
+                } else {
+                    Utils.showDialog(_("No results found"),
+                                     Gtk.MessageType.INFO, this._mainWindow);
+                }
+            }
+        });
+    }
+
+    _invalidMapsUri(uri) {
+        Utils.showDialog(_("Invalid maps: URI: %s").format(uri),
+                         Gtk.MessageType.ERROR, this._mainWindow);
+    }
+
     vfunc_open(files) {
-        normalStartup = false;
+        /* unless the first argument is a maps: URI with a search query
+         * we should not perform the normal startup behavior of going to
+         * the stored location, as shape layers, directly addressed OSM
+         * objects, and geo: URIs will override the startup location
+         */
+        let uri = files[0].get_uri();
+
+        if (GLib.uri_parse_scheme(uri) !== 'maps')
+            normalStartup = false;
+
         this.activate();
 
         let mapView = this._mainWindow.mapView;
@@ -368,26 +451,33 @@ var Application = GObject.registerClass({
         }
 
         let remaining = options.lookup(GLib.OPTION_REMAINING, null);
+        let files = [];
+
+        // when given the search CLI argument, insert URI as first file
+        if (options.contains('search')) {
+            let query = options.lookup_value('search', null).deep_unpack();
+
+            files = [Gio.File.new_for_uri(`maps:q=${query}`)];
+        }
 
         if (remaining) {
-            let files = [];
-
             remaining.forEach((r) => {
                 let path = r.get_string()[0];
 
                 if (path.startsWith('geo:') || path.startsWith('http://') ||
-                    path.startsWith('https://')) {
+                    path.startsWith('https://') || path.startsWith('maps:')) {
                     files.push(Gio.File.new_for_uri(path));
                 } else {
                     files.push(Gio.File.new_for_path(path));
                 }
             });
-
-            this.open(files, '');
-        } else {
-            this.activate();
         }
 
+        if (files.length > 0)
+            this.open(files, '');
+        else
+            this.activate();
+
         return 0;
     }
 
