@@ -70,7 +70,7 @@ var Geoclue = GObject.registerClass({
     }
 
     start(callback) {
-        let id = 'org.gnome.Maps';
+        let id = pkg.name;
         let level = GClue.AccuracyLevel.EXACT;
 
         GClue.Simple.new(id, level, null, (object, result) => {
@@ -90,9 +90,13 @@ var Geoclue = GObject.registerClass({
 
             this._simple.connect('notify::location',
                                  () => this._onLocationNotify(this._simple));
-            this._simple.client.connect('notify::active', () => {
-                this.state = this._simple.client.active ? State.ON : State.DENIED;
-            });
+
+            // geoclue doesn't use a client proxy inside the flatpak sandbox
+            if (this._simple.client) {
+                this._simple.client.connect('notify::active', () => {
+                    this.state = this._simple.client.active ? State.ON : State.DENIED;
+                });
+            }
 
             this.state = State.ON;
             this._onLocationNotify(this._simple);
@@ -115,7 +119,7 @@ var Geoclue = GObject.registerClass({
 
     _updateLocation(location) {
         if (!this.place)
-            this.place = new Place.Place({ name: _("Current location"),
+            this.place = new Place.Place({ name: _("Current Location"),
                                            isCurrentLocation: true });
 
         this.place.location = location;
