@@ -26,9 +26,11 @@ const Geocode = imports.gi.GeocodeGlib;
 const Gio = imports.gi.Gio;
 const Gtk = imports.gi.Gtk;
 const GtkChamplain = imports.gi.GtkChamplain;
+const Hdy = imports.gi.Handy;
 const Mainloop = imports.mainloop;
 
 const Application = imports.application;
+const BoundingBox = imports.boundingBox;
 const ContactPlace = imports.contactPlace;
 const Color = imports.color;
 const Geoclue = imports.geoclue;
@@ -173,7 +175,9 @@ var MapView = GObject.registerClass({
     }
 
     _initScale(view) {
-        this._scale = new Champlain.Scale({ visible: true });
+        let showScale = Application.settings.get('show-scale');
+
+        this._scale = new Champlain.Scale({ visible: showScale });
         this._scale.connect_view(view);
 
         if (Utils.getMeasurementSystem() === Utils.METRIC_SYSTEM)
@@ -209,8 +213,8 @@ var MapView = GObject.registerClass({
 
         // if dark tiles is available, setup handler to switch style
         if (Service.getService().tiles.streetDark) {
-            Application.settings.connect('changed::night-mode',
-                                         this._onNightModeChanged.bind(this));
+            Hdy.StyleManager.get_default().connect('notify::dark',
+                                                    this._onDarkChanged.bind(this));
         }
 
         // if hybrid aerial tiles are available, setup handler to toggle
@@ -223,6 +227,9 @@ var MapView = GObject.registerClass({
         this._gtkSettings.connect('notify::gtk-application-prefer-dark-theme',
                             this._onPreferDarkThemeChanged.bind(this));
 
+        Application.settings.connect('changed::show-scale',
+                                     this._onShowScaleChanged.bind(this));
+
         this._initScale(view);
         return view;
     }
@@ -271,11 +278,11 @@ var MapView = GObject.registerClass({
         this._setBackgroundPatternIfNeeded();
     }
 
-    _onNightModeChanged() {
+    _onDarkChanged() {
         if (this._mapType === MapType.STREET) {
             let overlay_sources = this.view.get_overlay_sources();
 
-            if (Application.settings.get('night-mode'))
+            if (Hdy.StyleManager.get_default().dark)
                 this.view.map_source = MapSource.createStreetDarkSource();
             else
                 this.view.map_source = MapSource.createStreetSource();
@@ -427,7 +434,7 @@ var MapView = GObject.registerClass({
                 }
             } else {
                 if (tiles.streetDark &&
-                    Application.settings.get('night-mode')) {
+                    Hdy.StyleManager.get_default().dark) {
                     this.view.map_source = MapSource.createStreetDarkSource();
                 } else {
                     this.view.map_source = MapSource.createStreetSource();
@@ -469,7 +476,13 @@ var MapView = GObject.registerClass({
     }
 
     toggleScale() {
-        this._scale.visible = !this._scale.visible;
+        let showScale = Application.settings.get('show-scale');
+
+        Application.settings.set('show-scale', !showScale);
+    }
+
+    _onShowScaleChanged() {
+        this._scale.visible = Application.settings.get('show-scale');
     }
 
     _checkIfFileSizeNeedsConfirmation(files) {
@@ -531,7 +544,7 @@ var MapView = GObject.registerClass({
     }
 
     _loadShapeLayers(files) {
-        let bbox = new Champlain.BoundingBox();
+        let bbox = new BoundingBox.BoundingBox();
         this._remainingFilesToLoad = files.length;
 
         files.forEach((file) => {
@@ -686,10 +699,10 @@ var MapView = GObject.registerClass({
                 Utils.debug('Invalid initial coordinates: ' + lat + ', ' + lon);
         } else {
             /* bounding box. for backwards compatibility, not used anymore */
-            let bbox = new Champlain.BoundingBox({ top: location[0],
-                                                   bottom: location[1],
-                                                   left: location[2],
-                                                   right: location[3] });
+            let bbox = new BoundingBox.BoundingBox({ top: location[0],
+                                                     bottom: location[1],
+                                                     left: location[2],
+                                                     right: location[3] });
             this.view.connect("notify::realized", () => {
                 if (this.view.realized)
                     this.gotoBBox(bbox, true);
@@ -698,12 +711,12 @@ var MapView = GObject.registerClass({
     }
 
     gotoBBox(bbox, linear) {
-        if (!bbox.is_valid()) {
+        if (!bbox.isValid()) {
             Utils.debug('Bounding box is invalid');
             return;
         }
 
-        let [lat, lon] = bbox.get_center();
+        let [lon, lat] = bbox.getCenter();
         let place = new Place.Place({
             location: new Location.Location({ latitude  : lat,
                                               longitude : lon }),
@@ -715,6 +728,33 @@ var MapView = GObject.registerClass({
         new MapWalker.MapWalker(place, this).goTo(true, linear);
     }
 
+    getZoomLevelFittingBBox(bbox) {
+        let mapSource = this.view.get_map_source();
+        let goodSize = false;
+        let zoomLevel = this.view.max_zoom_level;
+
+        do {
+
+            let minX = mapSource.get_x(zoomLevel, bbox.left);
+            let minY = mapSource.get_y(zoomLevel, bbox.bottom);
+            let maxX = mapSource.get_x(zoomLevel, bbox.right);
+            let maxY = mapSource.get_y(zoomLevel, bbox.top);
+
+            if (minY - maxY <= this.view.height &&
+                maxX - minX <= this.view.width)
+                goodSize = true;
+            else
+                zoomLevel--;
+
+            if (zoomLevel <= this.view.min_zoom_level) {
+                zoomLevel = this.view.min_zoom_level;
+                goodSize = true;
+            }
+        } while (!goodSize);
+
+        return zoomLevel;
+    }
+
     showTurnPoint(turnPoint) {
         if (this._turnPointMarker)
             this._turnPointMarker.destroy();
@@ -754,10 +794,7 @@ var MapView = GObject.registerClass({
             this._placeLayer.add_marker(marker);
         });
 
-        if (places.length > 1)
-            this.gotoBBox(contact.bounding_box);
-        else
-            new MapWalker.MapWalker(places[0], this).goTo(true);
+        new MapWalker.MapWalker(places[0], this).goTo(true);
     }
 
     _showStoredRoute(stored) {
