@@ -24,7 +24,6 @@ const Clutter = imports.gi.Clutter;
 const GObject = imports.gi.GObject;
 
 const MapMarker = imports.mapMarker;
-const UserLocationBubble = imports.userLocationBubble;
 
 var AccuracyCircleMarker = GObject.registerClass(
 class AccuracyCirleMarker extends Champlain.Point {
@@ -90,9 +89,8 @@ class UserLocationMarker extends MapMarker.MapMarker {
                  y: Math.floor(this.height / 2) };
     }
 
-    _createBubble() {
-        return new UserLocationBubble.UserLocationBubble({ place: this.place,
-                                                           mapView: this._mapView });
+    _hasBubble() {
+        return true;
     }
 
     addToLayer(layer) {
@@ -116,8 +114,6 @@ class UserLocationMarker extends MapMarker.MapMarker {
         this.add_actor(this._actor);
 
         this._updateAccuracyCircle();
-        if (this._bubble)
-            this._bubble.updateLocation();
     }
 
     _updateAccuracyCircle() {
